@@ -7,11 +7,11 @@ Information about the current version of the py-package-template package.
 
 __title__ = "abst"
 __description__ = (
-    "CLI Command making OCI Bastion simple and fast"
+    "CLI Command making OCI Bastion and kubernetes usage simple and fast"
 )
 
-__version__ = "1.3.6"
+__version__ = "1.6.2"
 __author__ = "Jiri Otoupal"
 __author_email__ = "jiri-otoupal@ips-database.eu"
-__license__ = "Apache 2.0"
+__license__ = "MIT"
 __url__ = "https://github.com/jiri-otoupal/abst"
